/* smartTrigger.h
   Triggers a scheme expression when player enters/leaves area

   Copyright (C) 2000  Mathias Broxvall

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef SMARTTRIGGER_H
#define SMARTTRIGGER_H

#include "gameHook.h"

class SmartTrigger : public GameHook {
 public:
  SmartTrigger(Real x, Real y, Real radius, SCM entering, SCM leaving);
  virtual ~SmartTrigger();
  virtual void releaseCallbacks();
  virtual void tick(Real);

  Real x, y, radius;

 private:
  bool wasIn;
  SCM entering, leaving;
};

#endif
